@@ -1,5 +1,4 @@
 /*
- * gedit-documents-commands.c
  * This file is part of gedit
  *
  * Copyright (C) 1998, 1999 Alex Roberts, Evan Lawrence
@@ -20,84 +19,71 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "config.h"
-
-#include "gedit-commands.h"
 #include "gedit-commands-private.h"
-
-#include <gtk/gtk.h>
-
 #include "gedit-window-private.h"
-#include "gedit-notebook.h"
-#include "gedit-debug.h"
 
 void
 _gedit_cmd_documents_previous_document (GSimpleAction *action,
-                                        GVariant      *parameter,
-                                        gpointer       user_data)
+					GVariant      *parameter,
+					gpointer       user_data)
 {
 	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GtkNotebook *notebook;
 
-	gedit_debug (DEBUG_COMMANDS);
-
 	notebook = GTK_NOTEBOOK (_gedit_window_get_notebook (window));
 	gtk_notebook_prev_page (notebook);
 }
 
 void
 _gedit_cmd_documents_next_document (GSimpleAction *action,
-                                    GVariant      *parameter,
-                                    gpointer       user_data)
+				    GVariant      *parameter,
+				    gpointer       user_data)
 {
 	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GtkNotebook *notebook;
 
-	gedit_debug (DEBUG_COMMANDS);
-
 	notebook = GTK_NOTEBOOK (_gedit_window_get_notebook (window));
 	gtk_notebook_next_page (notebook);
 }
 
 void
 _gedit_cmd_documents_move_to_new_window (GSimpleAction *action,
-                                         GVariant      *parameter,
-                                         gpointer       user_data)
+					 GVariant      *parameter,
+					 gpointer       user_data)
 {
 	GeditWindow *window = GEDIT_WINDOW (user_data);
 	GeditTab *tab;
 
-	gedit_debug (DEBUG_COMMANDS);
-
 	tab = gedit_window_get_active_tab (window);
 
-	if (tab == NULL)
-		return;
-
-	_gedit_window_move_tab_to_new_window (window, tab);
+	if (tab != NULL)
+	{
+		_gedit_window_move_tab_to_new_window (window, tab);
+	}
 }
 
-/* Methods releated with the tab groups */
+/* Methods related with the tab groups */
+
 void
 _gedit_cmd_documents_new_tab_group (GSimpleAction *action,
-                                    GVariant      *parameter,
-                                    gpointer       user_data)
+				    GVariant      *parameter,
+				    gpointer       user_data)
 {
 	gedit_multi_notebook_add_new_notebook (_gedit_window_get_multi_notebook (GEDIT_WINDOW (user_data)));
 }
 
 void
 _gedit_cmd_documents_previous_tab_group (GSimpleAction *action,
-                                         GVariant      *parameter,
-                                         gpointer       user_data)
+					 GVariant      *parameter,
+					 gpointer       user_data)
 {
 	gedit_multi_notebook_previous_notebook (_gedit_window_get_multi_notebook (GEDIT_WINDOW (user_data)));
 }
 
 void
 _gedit_cmd_documents_next_tab_group (GSimpleAction *action,
-                                     GVariant      *parameter,
-                                     gpointer       user_data)
+				     GVariant      *parameter,
+				     gpointer       user_data)
 {
 	gedit_multi_notebook_next_notebook (_gedit_window_get_multi_notebook (GEDIT_WINDOW (user_data)));
 }
