@@ -1,5 +1,4 @@
 /*
- * gedit-dirs.c
  * This file is part of gedit
  *
  * Copyright (C) 2008 Ignacio Casal Quinteiro
@@ -19,20 +18,18 @@
  */
 
 #include "config.h"
-
 #include "gedit-dirs.h"
 
 #if OS_MACOS
 #include <gtkosxapplication.h>
 #endif
 
-static gchar *user_config_dir        = NULL;
-static gchar *user_data_dir          = NULL;
-static gchar *user_styles_dir        = NULL;
-static gchar *user_plugins_dir       = NULL;
-static gchar *gedit_locale_dir       = NULL;
-static gchar *gedit_lib_dir          = NULL;
-static gchar *gedit_plugins_dir      = NULL;
+static gchar *user_config_dir = NULL;
+static gchar *user_data_dir = NULL;
+static gchar *user_plugins_dir = NULL;
+static gchar *gedit_locale_dir = NULL;
+static gchar *gedit_lib_dir = NULL;
+static gchar *gedit_plugins_dir = NULL;
 static gchar *gedit_plugins_data_dir = NULL;
 
 void
@@ -83,9 +80,7 @@ gedit_dirs_init (void)
 
 	if (gedit_locale_dir == NULL)
 	{
-		gedit_locale_dir = g_build_filename (DATADIR,
-						     "locale",
-						     NULL);
+		gedit_locale_dir = g_strdup (GEDIT_CONFIG_LOCALE_DIR);
 		gedit_lib_dir = g_build_filename (LIBDIR,
 						  "gedit",
 						  NULL);
@@ -101,9 +96,6 @@ gedit_dirs_init (void)
 	user_data_dir = g_build_filename (g_get_user_data_dir (),
 					  "gedit",
 					  NULL);
-	user_styles_dir = g_build_filename (user_data_dir,
-					    "styles",
-					    NULL);
 	user_plugins_dir = g_build_filename (user_data_dir,
 					     "plugins",
 					     NULL);
@@ -117,7 +109,6 @@ gedit_dirs_shutdown (void)
 {
 	g_clear_pointer (&user_config_dir, g_free);
 	g_clear_pointer (&user_data_dir, g_free);
-	g_clear_pointer (&user_styles_dir, g_free);
 	g_clear_pointer (&user_plugins_dir, g_free);
 	g_clear_pointer (&gedit_locale_dir, g_free);
 	g_clear_pointer (&gedit_lib_dir, g_free);
@@ -137,12 +128,6 @@ gedit_dirs_get_user_data_dir (void)
 	return user_data_dir;
 }
 
-const gchar *
-gedit_dirs_get_user_styles_dir (void)
-{
-	return user_styles_dir;
-}
-
 const gchar *
 gedit_dirs_get_user_plugins_dir (void)
 {
