@@ -27,29 +27,12 @@
 
 G_BEGIN_DECLS
 
-typedef struct
-{
-	GtkRecentManager *manager;
-	GtkRecentFilter *filter;
+void	gedit_recent_add_document	(GeditDocument *document);
 
-	gint limit;
-	gchar *substring_filter;
-
-	guint show_private : 1;
-	guint show_not_found : 1;
-	guint local_only : 1;
-} GeditRecentConfiguration;
-
-void		 gedit_recent_add_document		 (GeditDocument            *document);
-
-void		 gedit_recent_remove_if_local		 (GFile                    *location);
-
-void		 gedit_recent_configuration_init_default (GeditRecentConfiguration *config);
-void		 gedit_recent_configuration_destroy	 (GeditRecentConfiguration *config);
-GList		*gedit_recent_get_items			 (GeditRecentConfiguration *config);
+void	gedit_recent_remove_if_local	(GFile *location);
 
 G_END_DECLS
 
-#endif  /* GEDIT_RECENT_H  */
+#endif /* GEDIT_RECENT_H */
 
 /* ex:set ts=8 noet: */
