@@ -32,7 +32,7 @@ gchar 		*_gedit_tab_get_name			(GeditTab                *tab);
 
 gchar 		*_gedit_tab_get_tooltip			(GeditTab                *tab);
 
-GdkPixbuf 	*_gedit_tab_get_icon			(GeditTab                *tab);
+const gchar	*_gedit_tab_get_icon_name		(GeditTab                *tab);
 
 void		 _gedit_tab_revert			(GeditTab                *tab);
 
