@@ -1,5 +1,4 @@
 /*
- * gedit-view-frame.c
  * This file is part of gedit
  *
  * Copyright (C) 2010 - Ignacio Casal Quinteiro
@@ -16,21 +15,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with gedit; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * along with gedit. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "gedit-view-frame.h"
-
-#include <gtksourceview/gtksource.h>
-#include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
-#include <stdlib.h>
-
-#include "gedit-debug.h"
-#include "gedit-utils.h"
-#include "gedit-settings.h"
 #include "libgd/gd.h"
 
 #define FLUSH_TIMEOUT_DURATION 30 /* in seconds */
@@ -39,8 +28,9 @@
 
 typedef enum
 {
-	GOTO_LINE,
-	SEARCH
+	SEARCH_MODE_GOTO_LINE,
+	/* "Simple search", in contrast to "search and replace". */
+	SEARCH_MODE_SIMPLE_SEARCH,
 } SearchMode;
 
 typedef enum
@@ -354,7 +344,7 @@ start_search (GeditViewFrame *frame)
 	GtkSourceSearchContext *search_context;
 	GtkTextIter start_at;
 
-	g_return_if_fail (frame->search_mode == SEARCH);
+	g_return_if_fail (frame->search_mode == SEARCH_MODE_SIMPLE_SEARCH);
 
 	search_context = get_search_context (frame);
 
@@ -407,7 +397,7 @@ forward_search (GeditViewFrame *frame)
 	GtkTextBuffer *buffer;
 	GtkSourceSearchContext *search_context;
 
-	g_return_if_fail (frame->search_mode == SEARCH);
+	g_return_if_fail (frame->search_mode == SEARCH_MODE_SIMPLE_SEARCH);
 
 	search_context = get_search_context (frame);
 
@@ -465,7 +455,7 @@ backward_search (GeditViewFrame *frame)
 	GtkTextBuffer *buffer;
 	GtkSourceSearchContext *search_context;
 
-	g_return_if_fail (frame->search_mode == SEARCH);
+	g_return_if_fail (frame->search_mode == SEARCH_MODE_SIMPLE_SEARCH);
 
 	search_context = get_search_context (frame);
 
@@ -492,7 +482,7 @@ search_widget_scroll_event (GtkWidget      *widget,
                             GdkEventScroll *event,
                             GeditViewFrame *frame)
 {
-	if (frame->search_mode == GOTO_LINE)
+	if (frame->search_mode == SEARCH_MODE_GOTO_LINE)
 	{
 		return GDK_EVENT_PROPAGATE;
 	}
@@ -558,12 +548,12 @@ search_widget_key_press_event (GtkWidget      *widget,
 		return GDK_EVENT_STOP;
 	}
 
-	if (frame->search_mode == GOTO_LINE)
+	if (frame->search_mode == SEARCH_MODE_GOTO_LINE)
 	{
 		return GDK_EVENT_PROPAGATE;
 	}
 
-	/* SEARCH mode */
+	/* SEARCH_MODE_SIMPLE_SEARCH */
 
 	/* select previous matching iter */
 	if (event->keyval == GDK_KEY_Up || event->keyval == GDK_KEY_KP_Up)
@@ -604,7 +594,7 @@ update_entry_tag (GeditViewFrame *frame)
 	gint pos;
 	gchar *label;
 
-	if (frame->search_mode == GOTO_LINE)
+	if (frame->search_mode == SEARCH_MODE_GOTO_LINE)
 	{
 		gd_tagged_entry_remove_tag (frame->search_entry,
 					    frame->entry_tag);
@@ -843,20 +833,20 @@ search_entry_escaped (GtkSearchEntry *entry,
 {
 	GtkSourceSearchContext *search_context = get_search_context (frame);
 
-	if (frame->search_mode == SEARCH &&
+	if (frame->search_mode == SEARCH_MODE_SIMPLE_SEARCH &&
 	    search_context != NULL)
 	{
-		GtkSourceSearchContext *search_context;
+		GtkSourceSearchContext *new_search_context;
 		GtkTextBuffer *buffer;
 
 		g_clear_object (&frame->search_settings);
 		frame->search_settings = copy_search_settings (frame->old_search_settings);
 
 		buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (frame->view));
-		search_context = gtk_source_search_context_new (GTK_SOURCE_BUFFER (buffer),
-		                                                frame->search_settings);
-		gedit_document_set_search_context (GEDIT_DOCUMENT (buffer), search_context);
-		g_object_unref (search_context);
+		new_search_context = gtk_source_search_context_new (GTK_SOURCE_BUFFER (buffer),
+								    frame->search_settings);
+		gedit_document_set_search_context (GEDIT_DOCUMENT (buffer), new_search_context);
+		g_object_unref (new_search_context);
 
 		g_free (frame->search_text);
 		frame->search_text = NULL;
@@ -892,7 +882,7 @@ search_entry_populate_popup (GtkEntry       *entry,
 {
 	GtkWidget *menu_item;
 
-	if (frame->search_mode == GOTO_LINE)
+	if (frame->search_mode == SEARCH_MODE_GOTO_LINE)
 	{
 		return;
 	}
@@ -915,7 +905,7 @@ search_entry_icon_release (GtkEntry             *entry,
 {
 	GtkWidget *menu;
 
-	if (frame->search_mode == GOTO_LINE ||
+	if (frame->search_mode == SEARCH_MODE_GOTO_LINE ||
 	    icon_pos != GTK_ENTRY_ICON_PRIMARY)
 	{
 		return;
@@ -955,7 +945,7 @@ search_entry_insert_text (GtkEditable    *editable,
 	const gchar *end;
 	const gchar *next;
 
-	if (frame->search_mode == SEARCH)
+	if (frame->search_mode == SEARCH_MODE_SIMPLE_SEARCH)
 	{
 		return;
 	}
@@ -1013,7 +1003,7 @@ customize_for_search_mode (GeditViewFrame *frame)
 	GIcon *icon;
 	gint width_request;
 
-	if (frame->search_mode == SEARCH)
+	if (frame->search_mode == SEARCH_MODE_SIMPLE_SEARCH)
 	{
 		icon = g_themed_icon_new_with_default_fallbacks ("edit-find-symbolic");
 
@@ -1135,7 +1125,7 @@ search_entry_changed_cb (GtkEntry       *entry,
 {
 	renew_flush_timeout (frame);
 
-	if (frame->search_mode == SEARCH)
+	if (frame->search_mode == SEARCH_MODE_SIMPLE_SEARCH)
 	{
 		update_search_text (frame);
 		start_search (frame);
@@ -1207,7 +1197,7 @@ get_selected_text (GtkTextBuffer  *doc,
 static void
 init_search_entry (GeditViewFrame *frame)
 {
-	if (frame->search_mode == GOTO_LINE)
+	if (frame->search_mode == SEARCH_MODE_GOTO_LINE)
 	{
 		gint line;
 		gchar *line_str;
@@ -1228,7 +1218,7 @@ init_search_entry (GeditViewFrame *frame)
 	}
 	else
 	{
-		/* SEARCH mode */
+		/* SEARCH_MODE_SIMPLE_SEARCH */
 		GtkTextBuffer *buffer;
 		gboolean selection_exists;
 		gchar *search_text = NULL;
@@ -1368,7 +1358,7 @@ start_interactive_search_real (GeditViewFrame *frame,
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (frame->view));
 
-	if (frame->search_mode == SEARCH)
+	if (frame->search_mode == SEARCH_MODE_SIMPLE_SEARCH)
 	{
 		gtk_text_buffer_get_selection_bounds (buffer, &iter, NULL);
 	}
@@ -1450,8 +1440,6 @@ gedit_view_frame_init (GeditViewFrame *frame)
 	GeditDocument *doc;
 	GtkSourceFile *file;
 
-	gedit_debug (DEBUG_WINDOW);
-
 	gtk_widget_init_template (GTK_WIDGET (frame));
 
 	doc = get_document (frame);
@@ -1564,7 +1552,7 @@ gedit_view_frame_popup_search (GeditViewFrame *frame)
 {
 	g_return_if_fail (GEDIT_IS_VIEW_FRAME (frame));
 
-	start_interactive_search_real (frame, SEARCH);
+	start_interactive_search_real (frame, SEARCH_MODE_SIMPLE_SEARCH);
 }
 
 void
@@ -1572,7 +1560,7 @@ gedit_view_frame_popup_goto_line (GeditViewFrame *frame)
 {
 	g_return_if_fail (GEDIT_IS_VIEW_FRAME (frame));
 
-	start_interactive_search_real (frame, GOTO_LINE);
+	start_interactive_search_real (frame, SEARCH_MODE_GOTO_LINE);
 }
 
 void
