@@ -66,7 +66,7 @@ struct _GeditWindowPrivate
 
 	GeditSidePanel *side_panel;
 	GeditBottomPanel *bottom_panel;
-	gint bottom_panel_item_removed_handler_id;
+	gulong bottom_panel_remove_item_handler_id;
 
 	GtkWidget *hpaned;
 	GtkWidget *vpaned;
@@ -94,8 +94,6 @@ struct _GeditWindowPrivate
 	GtkHeaderBar *side_headerbar;
 	GeditHeaderBar *headerbar;
 
-	gint width;
-	gint height;
 	GdkWindowState window_state;
 
 	GeditWindowState state;
@@ -170,19 +168,6 @@ gedit_window_get_property (GObject    *object,
 	}
 }
 
-static void
-save_window_state (GeditWindow *window)
-{
-	if ((window->priv->window_state & GDK_WINDOW_STATE_MAXIMIZED) == 0 &&
-	    (window->priv->window_state & GDK_WINDOW_STATE_FULLSCREEN) == 0)
-	{
-		gtk_window_get_size (GTK_WINDOW (window), &window->priv->width, &window->priv->height);
-
-		g_settings_set (window->priv->window_settings, GEDIT_SETTINGS_WINDOW_SIZE,
-				"(ii)", window->priv->width, window->priv->height);
-	}
-}
-
 static void
 gedit_window_dispose (GObject *object)
 {
@@ -193,14 +178,14 @@ gedit_window_dispose (GObject *object)
 	/* Stop tracking removal of panels otherwise we always
 	 * end up with thinking we had no panel active, since they
 	 * should all be removed below */
-	if (window->priv->bottom_panel_item_removed_handler_id != 0)
+	if (window->priv->bottom_panel_remove_item_handler_id != 0)
 	{
-		GtkStack *stack;
+		TeplPanelSimple *panel_simple;
 
-		stack = _gedit_bottom_panel_get_stack (window->priv->bottom_panel);
+		panel_simple = _gedit_bottom_panel_get_panel_simple (window->priv->bottom_panel);
 
-		g_signal_handler_disconnect (stack, window->priv->bottom_panel_item_removed_handler_id);
-		window->priv->bottom_panel_item_removed_handler_id = 0;
+		g_signal_handler_disconnect (panel_simple, window->priv->bottom_panel_remove_item_handler_id);
+		window->priv->bottom_panel_remove_item_handler_id = 0;
 	}
 
 	/* First of all, force collection so that plugins
@@ -212,7 +197,6 @@ gedit_window_dispose (GObject *object)
 	 * for this window, but only once */
 	if (!window->priv->dispose_has_run)
 	{
-		save_window_state (window);
 		_gedit_side_panel_save_state (window->priv->side_panel);
 		_gedit_bottom_panel_save_state (window->priv->bottom_panel);
 		g_settings_apply (window->priv->window_settings);
@@ -298,10 +282,6 @@ gedit_window_window_state_event (GtkWidget           *widget,
 
 	window->priv->window_state = event->new_window_state;
 
-	g_settings_set_int (window->priv->window_settings,
-			    GEDIT_SETTINGS_WINDOW_STATE,
-			    window->priv->window_state);
-
 	if ((event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN) != 0)
 	{
 		update_fullscreen (window, (event->new_window_state & GDK_WINDOW_STATE_FULLSCREEN) != 0);
@@ -310,18 +290,6 @@ gedit_window_window_state_event (GtkWidget           *widget,
 	return GTK_WIDGET_CLASS (gedit_window_parent_class)->window_state_event (widget, event);
 }
 
-static gboolean
-gedit_window_configure_event (GtkWidget         *widget,
-			      GdkEventConfigure *event)
-{
-	if (gtk_widget_get_realized (widget))
-	{
-		save_window_state (GEDIT_WINDOW (widget));
-	}
-
-	return GTK_WIDGET_CLASS (gedit_window_parent_class)->configure_event (widget, event);
-}
-
 /*
  * GtkWindow catches keybindings for the menu items _before_ passing them to
  * the focused widget. This is unfortunate and means that pressing ctrl+V
@@ -392,7 +360,6 @@ gedit_window_class_init (GeditWindowClass *klass)
 	object_class->finalize = gedit_window_finalize;
 
 	widget_class->window_state_event = gedit_window_window_state_event;
-	widget_class->configure_event = gedit_window_configure_event;
 	widget_class->key_press_event = gedit_window_key_press_event;
 
 	/**
@@ -890,28 +857,6 @@ clone_window (GeditWindow *origin)
 
 	window = gedit_app_create_window (app, screen);
 
-	gtk_window_set_default_size (GTK_WINDOW (window),
-				     origin->priv->width,
-				     origin->priv->height);
-
-	if ((origin->priv->window_state & GDK_WINDOW_STATE_MAXIMIZED) != 0)
-	{
-		gtk_window_maximize (GTK_WINDOW (window));
-	}
-	else
-	{
-		gtk_window_unmaximize (GTK_WINDOW (window));
-	}
-
-	if ((origin->priv->window_state & GDK_WINDOW_STATE_STICKY) != 0)
-	{
-		gtk_window_stick (GTK_WINDOW (window));
-	}
-	else
-	{
-		gtk_window_unstick (GTK_WINDOW (window));
-	}
-
 	_gedit_side_panel_copy_settings (origin->priv->side_panel,
 					 window->priv->side_panel);
 	_gedit_bottom_panel_copy_settings (origin->priv->bottom_panel,
@@ -2012,18 +1957,20 @@ static void
 add_documents_panel (GeditWindow *window)
 {
 	GtkWidget *documents_panel;
-	TeplPanelContainer *panel_container;
+	TeplPanel *panel;
 	TeplPanelItem *item;
 
 	documents_panel = gedit_documents_panel_new (window);
 	gtk_widget_show_all (documents_panel);
 
-	panel_container = _gedit_side_panel_get_panel_container (window->priv->side_panel);
-	item = tepl_panel_add (TEPL_PANEL (panel_container),
-			       documents_panel,
-			       "GeditWindowDocumentsPanel",
-			       _("Documents"),
-			       NULL);
+	item = tepl_panel_item_new (documents_panel,
+				    "GeditWindowDocumentsPanel",
+				    _("Documents"),
+				    NULL,
+				    0);
+
+	panel = gedit_window_get_side_panel (window);
+	tepl_panel_add (panel, item);
 	g_object_unref (item);
 }
 
@@ -2039,9 +1986,9 @@ setup_side_panel (GeditWindow *window)
 }
 
 static void
-bottom_panel_visibility_changed (GtkWidget   *bottom_panel,
-                                 GParamSpec  *pspec,
-                                 GeditWindow *window)
+bottom_panel_visible_notify_cb (GtkWidget   *bottom_panel,
+				GParamSpec  *pspec,
+				GeditWindow *window)
 {
 	gboolean visible;
 	GAction *action;
@@ -2052,11 +1999,13 @@ bottom_panel_visibility_changed (GtkWidget   *bottom_panel,
 				GEDIT_SETTINGS_BOTTOM_PANEL_VISIBLE,
 				visible);
 
-	/* sync the action state if the panel visibility was changed programmatically */
+	/* Sync the action state if the panel visibility was changed
+	 * programmatically.
+	 */
 	action = g_action_map_lookup_action (G_ACTION_MAP (window), "bottom-panel");
 	g_simple_action_set_state (G_SIMPLE_ACTION (action), g_variant_new_boolean (visible));
 
-	/* focus the right widget */
+	/* Focus the right widget */
 	if (visible)
 	{
 		gtk_widget_grab_focus (GTK_WIDGET (window->priv->bottom_panel));
@@ -2068,11 +2017,18 @@ bottom_panel_visibility_changed (GtkWidget   *bottom_panel,
 }
 
 static void
-bottom_panel_item_removed (GtkStack    *bottom_panel_stack,
-			   GtkWidget   *item,
-			   GeditWindow *window)
+bottom_panel_remove_item_after_cb (TeplPanelSimple *panel_simple,
+				   TeplPanelItem   *item,
+				   GeditWindow     *window)
 {
-	if (gtk_stack_get_visible_child (bottom_panel_stack) == NULL)
+	GList *items;
+	guint n_items;
+
+	items = tepl_panel_simple_get_items (panel_simple);
+	n_items = g_list_length (items);
+	g_list_free_full (items, g_object_unref);
+
+	if (n_items == 0)
 	{
 		gtk_widget_hide (GTK_WIDGET (window->priv->bottom_panel));
 	}
@@ -2081,24 +2037,25 @@ bottom_panel_item_removed (GtkStack    *bottom_panel_stack,
 }
 
 static void
-bottom_panel_item_added (GtkStack    *bottom_panel_stack,
-			 GtkWidget   *item,
-			 GeditWindow *window)
+bottom_panel_add_item_after_cb (TeplPanelSimple *panel_simple,
+				TeplPanelItem   *item,
+				GeditWindow     *window)
 {
-	GList *children;
-	int n_children;
+	GList *items;
+	gint n_items;
 
-	children = gtk_container_get_children (GTK_CONTAINER (bottom_panel_stack));
-	n_children = g_list_length (children);
-	g_list_free (children);
+	items = tepl_panel_simple_get_items (panel_simple);
+	n_items = g_list_length (items);
+	g_list_free_full (items, g_object_unref);
 
 	/* First item added. */
-	if (n_children == 1)
+	if (n_items == 1)
 	{
 		gboolean show;
 
 		show = g_settings_get_boolean (window->priv->ui_settings,
-		                               "bottom-panel-visible");
+					       GEDIT_SETTINGS_BOTTOM_PANEL_VISIBLE);
+
 		if (show)
 		{
 			gtk_widget_show (GTK_WIDGET (window->priv->bottom_panel));
@@ -2111,28 +2068,40 @@ bottom_panel_item_added (GtkStack    *bottom_panel_stack,
 static void
 setup_bottom_panel (GeditWindow *window)
 {
-	gedit_debug (DEBUG_WINDOW);
-
-	g_signal_connect_after (window->priv->bottom_panel,
-	                        "notify::visible",
-	                        G_CALLBACK (bottom_panel_visibility_changed),
-	                        window);
+	g_signal_connect (window->priv->bottom_panel,
+			  "notify::visible",
+			  G_CALLBACK (bottom_panel_visible_notify_cb),
+			  window);
 }
 
 static void
 init_side_panel_visibility (GeditWindow *window)
 {
-	TeplPanelContainer *side_panel;
+	TeplPanelSimple *panel_simple;
 	gchar *item_name;
 	gboolean side_panel_visible;
 
-	side_panel = _gedit_side_panel_get_panel_container (window->priv->side_panel);
+	panel_simple = _gedit_side_panel_get_panel_simple (window->priv->side_panel);
 
 	item_name = g_settings_get_string (window->priv->window_settings,
 					   GEDIT_SETTINGS_SIDE_PANEL_ACTIVE_PAGE);
-	tepl_panel_container_set_active_item_name (side_panel, item_name);
+	tepl_panel_simple_set_active_item_name (panel_simple, item_name);
 	g_free (item_name);
 
+	if (tepl_panel_simple_get_active_item (panel_simple) == NULL)
+	{
+		GList *items;
+		TeplPanelItem *first_item;
+
+		items = tepl_panel_simple_get_items (panel_simple);
+		items = g_list_sort (items, (GCompareFunc) tepl_panel_item_compare);
+
+		first_item = items != NULL ? items->data : NULL;
+		tepl_panel_set_active (TEPL_PANEL (panel_simple), first_item);
+
+		g_list_free_full (items, g_object_unref);
+	}
+
 	side_panel_visible = g_settings_get_boolean (window->priv->ui_settings,
 						     GEDIT_SETTINGS_SIDE_PANEL_VISIBLE);
 
@@ -2145,28 +2114,26 @@ init_side_panel_visibility (GeditWindow *window)
 static void
 init_bottom_panel_visibility (GeditWindow *window)
 {
-	GtkStack *stack;
+	TeplPanelSimple *panel_simple;
+	GList *items;
+	guint n_items;
 
-	gedit_debug (DEBUG_WINDOW);
+	panel_simple = _gedit_bottom_panel_get_panel_simple (window->priv->bottom_panel);
 
-	stack = _gedit_bottom_panel_get_stack (window->priv->bottom_panel);
+	items = tepl_panel_simple_get_items (panel_simple);
+	n_items = g_list_length (items);
+	g_list_free_full (items, g_object_unref);
 
 	/* The bottom panel can be empty, in which case it isn't shown. */
-	if (gtk_stack_get_visible_child (stack) != NULL)
+	if (n_items > 0)
 	{
-		gchar *child_name;
-		GtkWidget *child_widget;
+		gchar *item_name;
 		gboolean bottom_panel_visible;
 
-		child_name = g_settings_get_string (window->priv->window_settings,
-						    GEDIT_SETTINGS_BOTTOM_PANEL_ACTIVE_PAGE);
-		child_widget = gtk_stack_get_child_by_name (stack, child_name);
-		if (child_widget != NULL)
-		{
-			gtk_stack_set_visible_child (stack, child_widget);
-		}
-
-		g_free (child_name);
+		item_name = g_settings_get_string (window->priv->window_settings,
+						   GEDIT_SETTINGS_BOTTOM_PANEL_ACTIVE_PAGE);
+		tepl_panel_simple_set_active_item_name (panel_simple, item_name);
+		g_free (item_name);
 
 		bottom_panel_visible = g_settings_get_boolean (window->priv->ui_settings,
 							       GEDIT_SETTINGS_BOTTOM_PANEL_VISIBLE);
@@ -2177,17 +2144,18 @@ init_bottom_panel_visibility (GeditWindow *window)
 		}
 	}
 
-	/* start track sensitivity after the initial state is set */
-	window->priv->bottom_panel_item_removed_handler_id =
-		g_signal_connect (stack,
-				  "remove",
-				  G_CALLBACK (bottom_panel_item_removed),
-				  window);
+	/* Start track sensitivity after the initial state is set. */
+	window->priv->bottom_panel_remove_item_handler_id =
+		g_signal_connect_after (panel_simple,
+					"remove-item",
+					G_CALLBACK (bottom_panel_remove_item_after_cb),
+					window);
 
-	g_signal_connect_after (stack,
-	                        "add",
-	                        G_CALLBACK (bottom_panel_item_added),
-	                        window);
+	g_signal_connect_object (panel_simple,
+				 "add-item",
+				 G_CALLBACK (bottom_panel_add_item_after_cb),
+				 window,
+				 G_CONNECT_AFTER);
 }
 
 static void
@@ -2360,7 +2328,7 @@ init_window_titles (GeditWindow *window)
 static void
 create_side_headerbar (GeditWindow *window)
 {
-	TeplPanelContainer *panel_container;
+	TeplPanelSimple *panel_simple;
 	TeplPanelSwitcherMenu *switcher;
 	GtkSizeGroup *size_group;
 
@@ -2369,8 +2337,8 @@ create_side_headerbar (GeditWindow *window)
 	window->priv->side_headerbar = GTK_HEADER_BAR (gtk_header_bar_new ());
 	gtk_header_bar_set_show_close_button (window->priv->side_headerbar, TRUE);
 
-	panel_container = _gedit_side_panel_get_panel_container (window->priv->side_panel);
-	switcher = tepl_panel_switcher_menu_new (panel_container);
+	panel_simple = _gedit_side_panel_get_panel_simple (window->priv->side_panel);
+	switcher = tepl_panel_switcher_menu_new (panel_simple);
 	gtk_widget_show (GTK_WIDGET (switcher));
 
 	gtk_header_bar_set_custom_title (window->priv->side_headerbar, GTK_WIDGET (switcher));
@@ -2448,25 +2416,33 @@ create_fullscreen_headerbar (GeditWindow *window)
 	}
 }
 
+static void
+init_window_state (GeditWindow *window)
+{
+	GeditSettings *gedit_settings;
+	GSettings *window_state_settings;
+
+	gedit_settings = _gedit_settings_get_singleton ();
+	window_state_settings = _gedit_settings_peek_window_state_settings (gedit_settings);
+
+	tepl_window_state_init (GTK_WINDOW (window),
+				window_state_settings,
+				GEDIT_TYPE_WINDOW);
+}
+
 static void
 gedit_window_init (GeditWindow *window)
 {
 	GtkTargetList *tl;
 
-	gedit_debug (DEBUG_WINDOW);
-
 	window->priv = gedit_window_get_instance_private (window);
 
-	window->priv->removing_tabs = FALSE;
 	window->priv->state = GEDIT_WINDOW_STATE_NORMAL;
-	window->priv->inhibition_cookie = 0;
-	window->priv->dispose_has_run = FALSE;
-	window->priv->direct_save_uri = NULL;
-	window->priv->closed_docs_stack = NULL;
 	window->priv->ui_settings = g_settings_new ("org.gnome.gedit.preferences.ui");
 
 	/* window settings are applied only once the window is closed. We do not
-	   want to keep writing to disk when the window is dragged around */
+	 * want to keep writing to disk when the window is dragged around.
+	 */
 	window->priv->window_settings = g_settings_new ("org.gnome.gedit.state.window");
 	g_settings_delay (window->priv->window_settings);
 
@@ -2474,6 +2450,8 @@ gedit_window_init (GeditWindow *window)
 
 	gtk_widget_init_template (GTK_WIDGET (window));
 
+	init_window_state (window);
+
 	init_amtk_application_window (window);
 
 	init_window_titles (window);
@@ -2484,10 +2462,10 @@ gedit_window_init (GeditWindow *window)
 
 	create_fullscreen_headerbar (window);
 
-	g_action_map_add_action_entries (G_ACTION_MAP (window),
-	                                 win_entries,
-	                                 G_N_ELEMENTS (win_entries),
-	                                 window);
+	amtk_action_map_add_action_entries_check_dups (G_ACTION_MAP (window),
+						       win_entries,
+						       G_N_ELEMENTS (win_entries),
+						       window);
 
 	window->priv->window_group = gtk_window_group_new ();
 	gtk_window_group_add_window (window->priv->window_group, GTK_WINDOW (window));
@@ -2495,7 +2473,6 @@ gedit_window_init (GeditWindow *window)
 	setup_fullscreen_eventbox (window);
 	sync_fullscreen_actions (window, FALSE);
 
-	/* Setup status bar */
 	setup_statusbar (window);
 
 	/* Setup main area */
@@ -2503,6 +2480,7 @@ gedit_window_init (GeditWindow *window)
 			  "notebook-removed",
 			  G_CALLBACK (on_notebook_removed),
 			  window);
+
 	g_signal_connect (window->priv->multi_notebook,
 			  "notify::active-notebook",
 			  G_CALLBACK (on_notebook_changed),
@@ -2534,16 +2512,16 @@ gedit_window_init (GeditWindow *window)
 			  window);
 
 	g_signal_connect (window->priv->multi_notebook,
-	                  "create-window",
-	                  G_CALLBACK (on_notebook_create_window),
-	                  window);
+			  "create-window",
+			  G_CALLBACK (on_notebook_create_window),
+			  window);
 
 	g_signal_connect (window->priv->multi_notebook,
 			  "show-popup-menu",
 			  G_CALLBACK (on_show_popup_menu),
 			  window);
 
-	/* side and bottom panels */
+	/* Panels */
 	setup_side_panel (window);
 	setup_bottom_panel (window);
 
@@ -2585,45 +2563,48 @@ gedit_window_init (GeditWindow *window)
 
 	gtk_target_list_add_uri_targets (tl, TARGET_URI_LIST);
 
-	/* connect instead of override, so that we can
-	 * share the cb code with the view */
+	/* Connect instead of override, so that we can share the cb code with
+	 * the view.
+	 */
 	g_signal_connect (window,
 			  "drag_data_received",
-	                  G_CALLBACK (drag_data_received_cb),
-	                  NULL);
+			  G_CALLBACK (drag_data_received_cb),
+			  NULL);
+
 	g_signal_connect (window,
 			  "drag_drop",
-	                  G_CALLBACK (drag_drop_cb),
-	                  NULL);
+			  G_CALLBACK (drag_drop_cb),
+			  NULL);
 
-	/* we can get the clipboard only after the widget
-	 * is realized */
+	/* We can get the clipboard only after the widget is realized. */
 	g_signal_connect (window,
 			  "realize",
 			  G_CALLBACK (window_realized),
 			  NULL);
+
 	g_signal_connect (window,
 			  "unrealize",
 			  G_CALLBACK (window_unrealized),
 			  NULL);
 
-	gedit_debug_message (DEBUG_WINDOW, "Update plugins ui");
-
 	window->priv->extensions = peas_extension_set_new (PEAS_ENGINE (gedit_plugins_engine_get_default ()),
 							   GEDIT_TYPE_WINDOW_ACTIVATABLE,
 							   "window", window,
 							   NULL);
+
 	g_signal_connect (window->priv->extensions,
 			  "extension-added",
 			  G_CALLBACK (extension_added),
 			  window);
+
 	g_signal_connect (window->priv->extensions,
 			  "extension-removed",
 			  G_CALLBACK (extension_removed),
 			  window);
+
 	peas_extension_set_foreach (window->priv->extensions,
-	                            (PeasExtensionSetForeachFunc) extension_added,
-	                            window);
+				    (PeasExtensionSetForeachFunc) extension_added,
+				    window);
 
 	/* Set visibility of panels. This needs to be done after plugins
 	 * activatation.
@@ -2632,8 +2613,6 @@ gedit_window_init (GeditWindow *window)
 	init_bottom_panel_visibility (window);
 
 	update_actions_sensitivity (window);
-
-	gedit_debug_message (DEBUG_WINDOW, "END");
 }
 
 /**
@@ -2976,7 +2955,7 @@ TeplPanel *
 gedit_window_get_side_panel (GeditWindow *window)
 {
 	g_return_val_if_fail (GEDIT_IS_WINDOW (window), NULL);
-	return TEPL_PANEL (_gedit_side_panel_get_panel_container (window->priv->side_panel));
+	return TEPL_PANEL (_gedit_side_panel_get_panel_simple (window->priv->side_panel));
 }
 
 GeditBottomPanel *
@@ -2990,14 +2969,14 @@ _gedit_window_get_whole_bottom_panel (GeditWindow *window)
  * gedit_window_get_bottom_panel:
  * @window: a #GeditWindow.
  *
- * Returns: (transfer none): the bottom panel's #GtkStack that is part of
- *   @window.
+ * Returns: (transfer none): the bottom panel of @window.
+ * Since: 48
  */
-GtkWidget *
+TeplPanel *
 gedit_window_get_bottom_panel (GeditWindow *window)
 {
 	g_return_val_if_fail (GEDIT_IS_WINDOW (window), NULL);
-	return GTK_WIDGET (_gedit_bottom_panel_get_stack (window->priv->bottom_panel));
+	return TEPL_PANEL (_gedit_bottom_panel_get_panel_simple (window->priv->bottom_panel));
 }
 
 /**
